@@ -15,7 +15,8 @@
 
 #include <QWidget>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class AbstractContactGroupFormatter;
 
 /**
@@ -50,7 +51,7 @@ public:
      *
      * @param parent The parent widget.
      */
-    ContactGroupViewer(QWidget *parent = nullptr);
+    explicit ContactGroupViewer(QWidget *parent = nullptr);
 
     /**
      * Destroys the contact group viewer.
