@@ -13,6 +13,7 @@
 #include "emailaddressselectionmodel.h"
 #include "emailaddressselectionproxymodel_p.h"
 
+#include <KLocalizedString>
 #include <changerecorder.h>
 #include <contactsfilterproxymodel.h>
 #include <contactstreemodel.h>
@@ -20,18 +21,17 @@
 #include <entitydisplayattribute.h>
 #include <entitytreeview.h>
 #include <itemfetchscope.h>
-#include <session.h>
 #include <kcontacts/addressee.h>
 #include <kcontacts/contactgroup.h>
-#include <KLocalizedString>
+#include <session.h>
 
-#include <QTimer>
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QKeyEvent>
 #include <QLabel>
-#include <QVBoxLayout>
 #include <QLineEdit>
+#include <QTimer>
+#include <QVBoxLayout>
 using namespace Akonadi;
 
 /**
@@ -46,6 +46,7 @@ public:
         , mReceiver(receiver)
     {
         setClearButtonEnabled(true);
+        installEventFilter(this);
     }
 
 protected:
@@ -57,6 +58,22 @@ protected:
 
         QLineEdit::keyPressEvent(event);
     }
+    bool eventFilter(QObject *obj, QEvent *event) override
+    {
+        if (obj == this) {
+            if (event->type() == QEvent::KeyPress) {
+                auto *e = static_cast<QKeyEvent *>(event);
+                if (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) {
+                    const bool stopEvent = (e->modifiers() == Qt::NoButton || e->modifiers() == Qt::KeypadModifier);
+                    if (stopEvent) {
+                        Q_EMIT returnPressed();
+                    }
+                    return true;
+                }
+            }
+        }
+        return QObject::eventFilter(obj, event);
+    }
 
 private:
     QWidget *const mReceiver;
@@ -78,7 +95,7 @@ public:
 
     void init();
 
-    EmailAddressSelectionWidget *q = nullptr;
+    EmailAddressSelectionWidget *const q;
     QAbstractItemModel *mModel = nullptr;
     QLabel *mDescriptionLabel = nullptr;
     SearchLineEdit *mSearchLine = nullptr;
@@ -135,11 +152,11 @@ void EmailAddressSelectionWidget::Private::init()
     mView->setModel(mSelectionModel);
     mView->header()->hide();
 
-    q->connect(mSearchLine, &QLineEdit::textChanged,
-               filter, &ContactsFilterProxyModel::setFilterString);
+    q->connect(mSearchLine, &QLineEdit::textChanged, filter, &ContactsFilterProxyModel::setFilterString);
 
-    q->connect(mView, QOverload<const Akonadi::Item &>::of(&Akonadi::EntityTreeView::doubleClicked),
-               q, [this]() { Q_EMIT q->doubleClicked(); });
+    q->connect(mView, QOverload<const Akonadi::Item &>::of(&Akonadi::EntityTreeView::doubleClicked), q, [this]() {
+        Q_EMIT q->doubleClicked();
+    });
     ControlGui::widgetNeedsAkonadi(q);
 
     mSearchLine->setFocus();
