@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,8 +14,8 @@ using namespace KAddressBookGrantlee;
 
 GrantleeContactViewer::GrantleeContactViewer(QWidget *parent)
     : Akonadi::ContactViewer(parent)
+    , mFormatter(new KAddressBookGrantlee::GrantleeContactFormatter)
 {
-    mFormatter = new KAddressBookGrantlee::GrantleeContactFormatter;
     setContactFormatter(mFormatter);
     mFormatter->setAbsoluteThemePath(kaddressBookAbsoluteThemePath());
 }
@@ -31,7 +31,8 @@ QString GrantleeContactViewer::kaddressBookAbsoluteThemePath()
     if (themeName.isEmpty()) {
         themeName = QStringLiteral("default");
     }
-    const QString absolutePath = GrantleeTheme::ThemeManager::pathFromThemes(QStringLiteral("kaddressbook/viewertemplates/"), themeName, QStringLiteral("theme.desktop"));
+    const QString absolutePath =
+        GrantleeTheme::ThemeManager::pathFromThemes(QStringLiteral("kaddressbook/viewertemplates/"), themeName, QStringLiteral("theme.desktop"));
     return absolutePath;
 }
 
