@@ -11,17 +11,19 @@
 #define MAILWIDGETLISTER_H
 
 #include "../../widgets/kwidgetlister_p.h"
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
-namespace ContactEditor {
+namespace ContactEditor
+{
 class MailWidget;
 class MailWidgetLister : public KWidgetLister
 {
     Q_OBJECT
 public:
     explicit MailWidgetLister(QWidget *parent = nullptr);
-    ~MailWidgetLister();
+    ~MailWidgetLister() override;
 
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
