@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,16 +12,16 @@
 #include <QIcon>
 #include <QTest>
 
-PreferredLineEditWidget::PreferredLineEditWidget(QObject *parent)
+PreferredLineEditWidgetTest::PreferredLineEditWidgetTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-PreferredLineEditWidget::~PreferredLineEditWidget()
+PreferredLineEditWidgetTest::~PreferredLineEditWidgetTest()
 {
 }
 
-void PreferredLineEditWidget::shouldHaveDefaultValue()
+void PreferredLineEditWidgetTest::shouldHaveDefaultValue()
 {
     ContactEditor::PreferredLineEditWidget w;
     auto *act = w.findChild<QAction *>(QStringLiteral("preferredaction"));
@@ -29,7 +29,7 @@ void PreferredLineEditWidget::shouldHaveDefaultValue()
     QVERIFY(!w.preferred());
 }
 
-void PreferredLineEditWidget::shouldChangePreferredValue()
+void PreferredLineEditWidgetTest::shouldChangePreferredValue()
 {
     ContactEditor::PreferredLineEditWidget w;
     auto *act = w.findChild<QAction *>(QStringLiteral("preferredaction"));
@@ -45,4 +45,4 @@ void PreferredLineEditWidget::shouldChangePreferredValue()
     QCOMPARE(act->icon(), enabled);
 }
 
-QTEST_MAIN(PreferredLineEditWidget)
+QTEST_MAIN(PreferredLineEditWidgetTest)
