@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,9 +9,10 @@
 #ifndef CONTACTEDITORCOMBOBOX_H
 #define CONTACTEDITORCOMBOBOX_H
 
-#include <QComboBox>
 #include "contacteditor_private_export.h"
-namespace ContactEditor {
+#include <QComboBox>
+namespace ContactEditor
+{
 class CONTACTEDITOR_TESTS_EXPORT ContactEditorComboBox : public QComboBox
 {
     Q_OBJECT
